@@ -1,6 +1,6 @@
-# Copyright (c) 2010-2011 Infrae. All rights reserved.
+# -*- coding: utf-8 -*-
+# Copyright (c) 2010-2013 Infrae. All rights reserved.
 # See also LICENSE.txt
-# $Id$
 
 from silva.core import conf as silvaconf
 
@@ -12,4 +12,6 @@ silvaconf.extension_system()
 CLASS_CHANGES = {
     'five.intid.keyreference KeyReferenceToPersistent':
         'silva.core.references.keyreference KeyReferenceToIItem',
+    'silva.core.references.interfaces IDeleteSourceOnTargetDeletion':
+        'zope.interface Interface',
     }
