@@ -1,21 +1,20 @@
-# Copyright (c) 2010-2011 Infrae. All rights reserved.
+# -*- coding: utf-8 -*-
+# Copyright (c) 2010-2013 Infrae. All rights reserved.
 # See also LICENSE.txt
-# $Id$
 
 import unittest
-import transaction
 
 from Acquisition import aq_chain
 from Products.Silva.testing import FunctionalLayer, TestCase
 
-from zope import component, interface
+from zope import component
 from zope.interface.verify import verifyObject
 
-from silva.core.references.reference import BrokenReferenceError
-from silva.core.references.reference import WeakReferenceValue
-from silva.core.references.reference import ReferenceSet, get_content_from_id
-from silva.core.references.interfaces import IReferenceService, IReferenceValue
-from silva.core.references.interfaces import IDeleteSourceOnTargetDeletion
+from ..reference import BrokenReferenceError
+from ..reference import WeakReferenceValue, DeleteSourceReferenceValue
+from ..reference import ReferenceSet, get_content_from_id
+from ..interfaces import IReferenceService, IReferenceValue
+from ..interfaces import IDeleteSourceReferenceValue, IWeakReferenceValue
 
 
 class SilvaReferenceTestCase(unittest.TestCase):
@@ -347,13 +346,13 @@ class SilvaReferenceDeletionTestCase(TestCase):
         reference.set_target(target)
         self.assertEquals(
             list(self.service.get_references_to(target)), [reference])
-        self.assertListEqual(
+        self.assertItemsEqual(
             self.root.pub.objectIds(), ['folder', 'source', 'target'])
 
         self.root.pub.manage_delObjects(['folder'],)
 
         self.assertEquals(list(self.service.get_references_to(target)), [])
-        self.assertListEqual(self.root.pub.objectIds(), ['source', 'target'])
+        self.assertItemsEqual(self.root.pub.objectIds(), ['source', 'target'])
 
     def test_delete_container_source_outside(self):
         """Now we delete a folder that contain a content which is a
@@ -365,24 +364,15 @@ class SilvaReferenceDeletionTestCase(TestCase):
             self.root.pub.source, name=u"simple reference")
         target = self.root.pub.folder.target
         reference.set_target(target)
-        # You can't break a reference you create in the same
-        # request. So we need to commit here in order to get the
-        # transaction.abort() working.
-        transaction.commit()
 
         self.assertEquals(
             list(self.service.get_references_to(target)), [reference])
-        self.assertListEqual(
+        self.assertItemsEqual(
             self.root.pub.objectIds(), ['folder', 'source', 'target'])
 
         self.assertRaises(
             BrokenReferenceError, self.root.pub.manage_delObjects, ['folder'])
 
-        self.assertEquals(
-            list(self.service.get_references_to(target)), [reference])
-        self.assertListEqual(
-            self.root.pub.objectIds(), ['folder', 'source', 'target'])
-
     def test_delete_container_with_source_and_target(self):
         """In that test we deleted the source and the target of a
         relation in one shoot by deleting a container that contains
@@ -397,13 +387,13 @@ class SilvaReferenceDeletionTestCase(TestCase):
 
         self.assertEquals(
             list(self.service.get_references_to(target)), [reference])
-        self.assertListEqual(
+        self.assertItemsEqual(
             self.root.pub.objectIds(), ['folder', 'source', 'target'])
 
         self.root.pub.manage_delObjects(['folder'],)
 
         self.assertEquals(list(self.service.get_references_to(target)), [])
-        self.assertListEqual(self.root.pub.objectIds(), ['source', 'target'])
+        self.assertItemsEqual(self.root.pub.objectIds(), ['source', 'target'])
 
     def test_delete_container_with_source_and_target_acquisition_bug(self):
         """In that test we deleted the source and the target of a
@@ -428,33 +418,34 @@ class SilvaReferenceDeletionTestCase(TestCase):
 
         self.assertEquals(
             list(self.service.get_references_to(target)), [reference])
-        self.assertListEqual(
+        self.assertItemsEqual(
             self.root.pub.objectIds(), ['folder', 'source', 'target'])
 
         self.root.pub.manage_delObjects(['folder'],)
 
         self.assertEquals(list(self.service.get_references_to(target)), [])
-        self.assertListEqual(self.root.pub.objectIds(), ['source', 'target'])
+        self.assertItemsEqual(self.root.pub.objectIds(), ['source', 'target'])
 
     def test_delete_source_if_delete_target(self):
         """In that test, we want to delete the source anyway if the
         target is deleted.
         """
         reference = self.service.new_reference(
-            self.root.pub.source, name=u"simple reference")
+            self.root.pub.source, name=u"simple reference",
+            factory=DeleteSourceReferenceValue)
         target = self.root.pub.folder.target
-        interface.alsoProvides(reference, IDeleteSourceOnTargetDeletion)
         reference.set_target(target)
+        self.assertTrue(verifyObject(IDeleteSourceReferenceValue, reference))
 
         self.assertEquals(
             list(self.service.get_references_to(target)), [reference])
-        self.assertListEqual(
+        self.assertItemsEqual(
             self.root.pub.objectIds(), ['folder', 'source', 'target'])
 
         self.root.pub.manage_delObjects(['folder'],)
 
         self.assertEquals(list(self.service.get_references_to(target)), [])
-        self.assertListEqual(self.root.pub.objectIds(), ['target'])
+        self.assertItemsEqual(self.root.pub.objectIds(), ['target'])
 
     def test_delete_weak_reference(self):
         """Delete the target of a weak reference. Nothing wrong should happen.
@@ -463,6 +454,7 @@ class SilvaReferenceDeletionTestCase(TestCase):
             self.root.pub.source, name=u'weak ref', factory=WeakReferenceValue)
         target = self.root.pub.folder.target
         reference.set_target(target)
+        self.assertTrue(verifyObject(IWeakReferenceValue, reference))
 
         self.root.pub.folder.manage_delObjects(['target'])
 
